@@ -5,7 +5,8 @@
 
 extern "C" {
   SEXP xbart(SEXP controlExpr, SEXP modelExpr, SEXP dataExpr, SEXP methodExpr,
-             SEXP testSampleSizeExpr, SEXP numRepsExpr, SEXP numBurnInExpr, SEXP lossTypeExpr, SEXP numThreadsExpr,
+             SEXP testSampleSizeExpr, SEXP numRepsExpr, SEXP numBurnInExpr,
+             SEXP lossTypeExpr, SEXP numThreadsExpr,
              SEXP numTreesExpr, SEXP kExpr, SEXP powerExpr, SEXP baseExpr,
              SEXP dropExpr);
 }
