@@ -10,8 +10,17 @@
 
 #include <misc/alloca.h>
 
+// R includes
+#include <Rversion.h>
+
+#if R_VERSION >= R_Version(3, 6, 2)
+#define USE_FC_LEN_T
+#endif
+
 #include <R_ext/Random.h> // GetRNGstate, PutRNGState
 
+#undef USE_FC_LEN_T
+
 #include <rc/bounds.h>
 #include <rc/util.h>
 
