@@ -19,30 +19,35 @@ using std::size_t;
 using std::uint32_t;
 
 namespace dbarts {
-  NormalPrior::NormalPrior(const Control& control, const Model& model, double k)
-  {
-    double sigma = model.nodeScale / (k * std::sqrt(static_cast<double>(control.numTrees)));
-    precision = 1.0 / (sigma * sigma);
-  }
+  NormalPrior::NormalPrior(const Control& control, const Model& model) :
+      scale(model.nodeScale / std::sqrt(static_cast<double>(control.numTrees)))
+    { }
   
-  double NormalPrior::drawFromPosterior(ext_rng* rng, double ybar, double numEffectiveObservations, double residualVariance) const {
+  double NormalPrior::drawFromPosterior(ext_rng* rng, double k, double ybar, double numEffectiveObservations, double residualVariance) const
+  {
+    double priorPrecision = (k / scale) * (k / scale);
+    
     double posteriorPrecision = numEffectiveObservations / residualVariance;
     
-    double posteriorMean = posteriorPrecision * ybar / (this->precision + posteriorPrecision);
-    double posteriorSd   = 1.0 / std::sqrt(this->precision + posteriorPrecision);
+    double posteriorMean = posteriorPrecision * ybar / (priorPrecision + posteriorPrecision);
+    double posteriorSd   = 1.0 / std::sqrt(priorPrecision + posteriorPrecision);
     
     return posteriorMean + posteriorSd * ext_rng_simulateStandardNormal(rng);
   }
   
-  double NormalPrior::drawFromPrior(ext_rng* rng) const {
-    return ext_rng_simulateStandardNormal(rng) / std::sqrt(this->precision);
+  double NormalPrior::drawFromPrior(ext_rng* rng, double k) const {
+    double priorSD = scale / k;
+    
+    return ext_rng_simulateStandardNormal(rng) * priorSD;
   }
   
-  double NormalPrior::computeLogIntegratedLikelihood(const BARTFit& fit, size_t chainNum, const Node& node, const double* y, double residualVariance) const
+  double NormalPrior::computeLogIntegratedLikelihood(const BARTFit& fit, size_t chainNum, double k, const Node& node, const double* y, double residualVariance) const
   {
     size_t numObservationsInNode = node.getNumObservations();
     if (numObservationsInNode == 0) return 0.0;
     
+    double priorPrecision = (k / scale) * (k / scale);
+    
     double y_bar = node.getAverage();
     double var_y = node.computeVariance(fit, chainNum, y);
       
@@ -57,24 +62,20 @@ namespace dbarts {
     double result;
     // we divide out by the actual n - 1 instead of a weighted sum because the variance
     // divides that number regardless; the calculations are correct in both cases
-    result  = 0.5 * std::log(this->precision / (this->precision + posteriorPrecision));
+    result  = 0.5 * std::log(priorPrecision / (priorPrecision + posteriorPrecision));
     result -= 0.5 * (var_y / residualVariance) * static_cast<double>(numObservationsInNode - 1);
-    result -= 0.5 * ((this->precision * y_bar) * (posteriorPrecision * y_bar)) / (this->precision + posteriorPrecision);
+    result -= 0.5 * ((priorPrecision * y_bar) * (posteriorPrecision * y_bar)) / (priorPrecision + posteriorPrecision);
     
     return result;
   }
   
-  void NormalPrior::setK(const BARTFit& fit, double k) {
-    double sigma = fit.model.nodeScale / (k * std::sqrt(static_cast<double>(fit.control.numTrees)));
-    precision = 1.0 / (sigma * sigma);
+  void NormalPrior::setScale(const Control& control, const Model& model) {
+    scale = model.nodeScale / std::sqrt(static_cast<double>(control.numTrees));
   }
-  
-  double NormalPrior::getK(const BARTFit& fit) const {
-    double sigma = std::sqrt(1.0 / precision);
-    return fit.model.nodeScale / (sigma * std::sqrt(static_cast<double>(fit.control.numTrees)));
-  }
-  
+
+    
   ChiSquaredPrior::ChiSquaredPrior(double degreesOfFreedom, double quantile) :
+    ResidualVariancePrior(false),
     degreesOfFreedom(degreesOfFreedom),
     scale(ext_quantileOfChiSquared(1.0 - quantile, degreesOfFreedom) / degreesOfFreedom)
   {
@@ -135,6 +136,11 @@ namespace dbarts {
     ext_printf("\tprior on k: chi with %f degrees of freedom and %f scale\n", degreesOfFreedom, scale);
   }
   
+  void FixedHyperprior::print(const BARTFit&) const
+  {
+    ext_printf("\tk prior fixed to %f\n", k);
+  }
+  
   double ChiHyperprior::drawFromPosterior(const BARTFit& fit, size_t chainNum) const
   {
     const Control& control(fit.control);
@@ -166,3 +172,4 @@ namespace dbarts {
     return std::sqrt(ext_rng_simulateGamma(state.rng, shape, 1.0 / rate));
   }
 }
+
